@@ -58,7 +58,8 @@ class Kola(kola.Kola, TCPServer):
 
                 return result
 
-            self.events.repeat_timer += safe_func(func_wrapper)
+            self.events.repeat_timer += functools.partial(IOLoop.instance().add_timeout,
+                                                          time.time() + interval, func_wrapper)
             return func_wrapper
         return inner_repeat_timer
 
