@@ -27,6 +27,7 @@ class Blueprint(kola.Blueprint):
 
                 return result
 
-            self.events.repeat_app_timer += safe_func(func_wrapper)
+            self.events.repeat_app_timer += functools.partial(IOLoop.instance().add_timeout,
+                                                              time.time() + interval, func_wrapper)
             return func_wrapper
         return inner_repeat_timer
